﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.Drawing.Drawing2D;

namespace howto_draw_curves
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // True when we are drawing.
        private bool Drawing = true;

        // The currently selected points.
        private List<Point> Points = new List<Point>();

        // The curve's tension.
        private float Tension = 0.5f;

        // The user clicked. Add a point,
        // stop drawing, or start a new curve.
        private void picCanvas_MouseClick(object sender, MouseEventArgs e)
        {
            // See if we are currently drawing.
            if (Drawing)
            {
                // See if this is the left or right mouse button.
                if (e.Button == MouseButtons.Left)
                {
                    // Left button. Add a new point.
                    Points.Add(e.Location);
                }
                else
                {
                    // Right button. Stop drawing.
                    Drawing = false;
                }
            }
            else
            {
                // We are not drawing. Start a new curve.
                Drawing = true;
                Points = new List<Point>();

                // Add a new point.
                Points.Add(e.Location);
            }

            // Redraw.
            picCanvas.Refresh();
        }

        // Draw the curve and its points.
        private void picCanvas_Paint(object sender, PaintEventArgs e)
        {
            e.Graphics.SmoothingMode = SmoothingMode.AntiAlias;

            // Draw the curve.
            if (Points.Count > 1)
            {
                // Make a pen to use.
                using (Pen pen = new Pen(Color.Blue))
                {
                    // See if we're currently drawing.
                    if (Drawing)
                    {
                        // Use a dashed pen.
                        pen.DashPattern = new float[] { 5, 5 };
                    }

                    // Draw the curve.
                    e.Graphics.DrawCurve(pen, Points.ToArray(), Tension);
                }
            }

            // Draw the points.
            if (Drawing && (Points.Count > 0))
            {
                const int r = 4;
                foreach (Point point in Points)
                {
                    Rectangle rect = new Rectangle(
                        point.X - r, point.Y - r, 2 * r, 2 * r);
                    e.Graphics.FillRectangle(Brushes.White, rect);
                    e.Graphics.DrawRectangle(Pens.Black, rect);
                }
            }
        }

        // Adjust the curve's tension.
        private void scrTension_Scroll(object sender, ScrollEventArgs e)
        {
            Tension = scrTension.Value / 10f;
            lblTension.Text = Tension.ToString();
            picCanvas.Refresh();
        }
    }
}
